@@ -2,4 +2,4 @@ from pyramid.scaffolds import PyramidTemplate
 
 class PyJinAlTemplate(PyramidTemplate):
     _template_dir = 'pyjinal_scaffold'
-    summary = 'Scaffold for getting started with Jinja2 and SQLAlchemy'
+    summary = 'Pyramid project with Jinja2 and SQLAlchemy'
